@@ -5,11 +5,11 @@ use std::{fmt::Debug, hash::Hash, marker::Sync};
 mod tests {
     use super::*;
 
-    fn setup<T>(list: &[T], expected: &[(T, u32)])
+    fn setup<T>(list: &[T], expected: &[(T, u64)])
     where
         T: Copy + Eq + Hash + Debug + Sync + Send,
     {
-        let frequency_table = frequency_finder(list, 6);
+        let frequency_table = frequency_finder(list);
 
         println!("{:?}", frequency_table);
 
@@ -82,9 +82,9 @@ mod tests {
 
     #[test]
     fn slice_1() {
-        let list = ["hi", "who", "me", "who", "me", "hi"];
+        let list = ["hi", "who", "me", "me", "hi"];
 
-        let expected = [("hi", 2), ("who", 2), ("me", 2)];
+        let expected = [("hi", 2), ("who", 1), ("me", 2)];
 
         setup(&list, &expected);
     }
